/*
 * Copyright (c) 2010-2019 Belledonne Communications SARL.
 *
 * This file is part of mediastreamer2.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef OPENGL_FUNCTIONS_H
#define OPENGL_FUNCTIONS_H

#include "mediastreamer2/msogl_functions.h"

// -----------------------------------------------------------------------------
#if defined __cplusplus
extern "C" {
#endif
void opengl_functions_default_init (OpenGlFunctions *f);
#if defined __cplusplus
}//extern "C"
#endif

#endif
